"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_server_core_1 = require("apollo-server-core");
const graphql_playground_html_1 = require("@apollographql/graphql-playground-html");
const nativeApollo_1 = require("./nativeApollo");
class ApolloServer extends apollo_server_core_1.ApolloServerBase {
    async createGraphQLServerOptions(req, res) {
        return super.graphQLServerOptions({ req, res });
    }
    supportsSubscriptions() {
        return true;
    }
    supportsUploads() {
        return false;
    }
    createHandler({ path } = {}) {
        this.graphqlPath = path ? path : '/graphql';
        const promiseWillStart = this.willStart();
        return async (req, res) => {
            await promiseWillStart;
            if (this.playgroundOptions && req.method === 'GET') {
                const playgroundRenderPageOptions = {
                    endpoint: this.graphqlPath,
                    subscriptionEndpoint: this.subscriptionsPath,
                    ...this.playgroundOptions,
                };
                const playground = graphql_playground_html_1.renderPlaygroundPage(playgroundRenderPageOptions);
                res.setHeader('content-type', 'text/html');
                res.write(playground);
                res.end();
                return;
            }
            nativeApollo_1.graphqlNative(() => this.createGraphQLServerOptions(req, res))(req, res);
        };
    }
}
exports.ApolloServer = ApolloServer;
//# sourceMappingURL=ApolloServer.js.map